@@ -290,6 +290,51 @@ couchdb_document_remove_field (CouchdbDocument *document, const char *field)
 	json_object_remove_member (document->priv->root_object, field);
 }
 
+/**
+ * couchdb_document_get_field_names:
+ * @document: A #CouchdbDocument object
+ *
+ * Retrieve the list of fields contained in the given #CouchdbDocument.
+ *
+ * Return value: A list of strings containing the names of all the fields contained
+ * in the given #CouchdbDocument object. When no longer needed, the list should
+ * be freed by calling #g_slist_free.
+ */
+GSList *
+couchdb_document_get_field_names (CouchdbDocument *document)
+{
+	GList *json_list;
+	GSList *result = NULL;
+
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
+
+	json_list = json_object_get_members (document->priv->root_object);
+	while (json_list != NULL) {
+		result = g_slist_append (result, json_list->data);
+
+		json_list = g_list_remove (json_list, json_list->data);
+	}
+
+	return result;
+}
+
+/**
+ * couchdb_document_get_field_type:
+ * @document: A #CouchdbDocument object
+ * @field: Name of the field to get type
+ *
+ * Get the value type of the given #CouchdbDocument's field.
+ *
+ * Return value: Type of the field.
+ */
+GType
+couchdb_document_get_field_type (CouchdbDocument *document, const char *field)
+{
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), G_TYPE_INVALID);
+
+	return get_type_from_field (document->priv->root_object, field);
+}
+
 /**
  * couchdb_document_get_array_field:
  * @document: A #CouchdbDocument object
