@@ -50,7 +50,6 @@ typedef struct {
 	GObjectClass parent_class;
 } CouchdbDocumentClass;
 
-
 GType               couchdb_document_get_type (void);
 
 CouchdbDocument    *couchdb_document_new (void);
@@ -62,6 +61,8 @@ void                couchdb_document_set_revision (CouchdbDocument *document, co
 
 gboolean            couchdb_document_has_field (CouchdbDocument *document, const char *field);
 void                couchdb_document_remove_field (CouchdbDocument *document, const char *field);
+GSList             *couchdb_document_get_field_names (CouchdbDocument *document);
+GType               couchdb_document_get_field_type (CouchdbDocument *document, const char *field);
 
 CouchdbArrayField  *couchdb_document_get_array_field (CouchdbDocument *document, const char *field);
 void                couchdb_document_set_array_field (CouchdbDocument *document, const char *field, CouchdbArrayField *value);
