@@ -188,6 +188,23 @@ couchdb_struct_field_get_field_names (CouchdbStructField *sf)
 	return result;
 }
 
+/**
+ * couchdb_struct_field_get_field_type:
+ * @sf: A #CouchdbStructField object
+ * @field: Name of the field to get type
+ *
+ * Get the value type of the given #CouchdbStructField's field.
+ *
+ * Return value: Type of the field.
+ */
+GType
+couchdb_struct_field_get_field_type (CouchdbStructField *sf, const char *field)
+{
+	g_return_val_if_fail (COUCHDB_IS_STRUCT_FIELD (sf), G_TYPE_INVALID);
+
+	return get_type_from_field (sf->priv->json_object, field);
+}
+
 /**
  * couchdb_struct_field_get_array_field:
  * @sf: A #CouchdbStructField object
